@@ -1,8 +1,8 @@
 #ifndef S7_H
 #define S7_H
 
-#define S7_VERSION "8.1"
-#define S7_DATE "4-Jan-19"
+#define S7_VERSION "8.5"
+#define S7_DATE "23-May-19"
 
 #include <stdint.h>           /* for int64_t */
 
@@ -121,12 +121,15 @@ bool s7_history_enabled(s7_scheme *sc);
 bool s7_set_history_enabled(s7_scheme *sc, bool enabled);
 
 s7_pointer s7_gc_on(s7_scheme *sc, bool on);                         /* (gc on) */
-void s7_gc_stats(s7_scheme *sc, bool on);                            /* (*s7* 'gc-stats) */
+void s7_set_gc_stats(s7_scheme *sc, bool on);                        /* (set! (*s7* 'gc-stats) on) */
 
 s7_int s7_gc_protect(s7_scheme *sc, s7_pointer x);
 void s7_gc_unprotect_at(s7_scheme *sc, s7_int loc);
 s7_pointer s7_gc_protected_at(s7_scheme *sc, s7_int loc);
 s7_pointer s7_gc_protect_via_stack(s7_scheme *sc, s7_pointer x);
+s7_pointer s7_gc_unprotect_via_stack(s7_scheme *sc, s7_pointer x);
+s7_pointer s7_gc_protect_via_location(s7_scheme *sc, s7_pointer x, s7_int loc);
+s7_pointer s7_gc_unprotect_via_location(s7_scheme *sc, s7_int loc);
 
   /* any s7_pointer object held in C (as a local variable for example) needs to be
    *   protected from garbage collection if there is any chance the GC may run without
@@ -291,11 +294,6 @@ s7_pointer s7_make_and_fill_vector(s7_scheme *sc, s7_int len, s7_pointer fill);
 void s7_vector_fill(s7_scheme *sc, s7_pointer vec, s7_pointer obj);                   /* (vector-fill! vec obj) */
 s7_pointer s7_vector_copy(s7_scheme *sc, s7_pointer old_vect);
 s7_pointer s7_vector_to_list(s7_scheme *sc, s7_pointer vect);                         /* (vector->list vec) */
-
-
-s7_int s7_print_length(s7_scheme *sc);                                                /* value of (*s7* 'print-length) */
-s7_int s7_set_print_length(s7_scheme *sc, s7_int new_len);                            /* sets (*s7* 'print-length), returns old value */
-
   /* 
    *  (vect i) is the same as (vector-ref vect i)
    *  (set! (vect i) x) is the same as (vector-set! vect i x)
@@ -303,8 +301,7 @@ s7_int s7_set_print_length(s7_scheme *sc, s7_int new_len);
    *  (set! (vect i j k) x) sets that element (vector-ref and vector-set! can also be used)
    *  (make-vector (list 2 3 4)) returns a 3-dimensional vector with the given dimension sizes
    *  (make-vector '(2 3) 1.0) returns a 2-dim vector with all elements set to 1.0
-   */
-  
+   */  
 
 bool s7_is_hash_table(s7_pointer p);                                        /* (hash-table? p) */
 s7_pointer s7_make_hash_table(s7_scheme *sc, s7_int size);                  /* (make-hash-table size) */
@@ -572,6 +569,12 @@ s7_pointer s7_fill(s7_scheme *sc, s7_pointer args);            /* (fill! ...) */
 s7_pointer s7_type_of(s7_scheme *sc, s7_pointer arg);          /* (type-of arg) */
 
 
+s7_int s7_print_length(s7_scheme *sc);                                                /* value of (*s7* 'print-length) */
+s7_int s7_set_print_length(s7_scheme *sc, s7_int new_len);                            /* sets (*s7* 'print-length), returns old value */
+s7_int s7_float_format_precision(s7_scheme *sc);                                      /* value of (*s7* 'float-format-precision) */
+s7_int s7_set_float_format_precision(s7_scheme *sc, s7_int new_len);                  /* sets (*s7* 'float-format-precision), returns old value */
+
+
 
 /* -------------------------------------------------------------------------------- */
 /* c types/objects */
@@ -585,7 +588,7 @@ void *s7_c_object_value_checked(s7_pointer obj, s7_int type);
 s7_pointer s7_make_c_object(s7_scheme *sc, s7_int type, void *value);
 s7_pointer s7_make_c_object_with_let(s7_scheme *sc, s7_int type, void *value, s7_pointer let);
 s7_pointer s7_c_object_let(s7_pointer obj);
-s7_pointer s7_c_object_set_let(s7_pointer obj, s7_pointer e);
+s7_pointer s7_c_object_set_let(s7_scheme *sc, s7_pointer obj, s7_pointer e);
 
 s7_int s7_make_c_type(s7_scheme *sc, const char *name);
 void s7_c_type_set_free     (s7_scheme *sc, s7_int tag, void (*gc_free)(void *value));
@@ -833,10 +836,6 @@ s7_pointer s7_apply_n_9(s7_scheme *sc, s7_pointer args,
 typedef s7_int s7_Int;
 typedef s7_double s7_Double;
 
-#define s7_is_morally_equal           s7_is_equivalent
-#define s7_is_ulong(arg)              s7_is_integer(arg)
-#define s7_ulong(p)                   (uint64_t)s7_integer(p)
-#define s7_make_ulong(sc, n)          s7_make_integer(sc, (s7_int)n)
 #define s7_is_object                  s7_is_c_object
 #define s7_object_type                s7_c_object_type
 #define s7_object_value               s7_c_object_value
@@ -846,7 +845,9 @@ typedef s7_double s7_Double;
 #define s7_NIL(Sc)                    s7_nil(Sc)
 #define s7_new_type(Name, Print, GC_Free, Equal, Mark, Ref, Set) s7_new_type_1(s7, Name, Print, GC_Free, Equal, Mark, Ref, Set)
 
-void s7_gc_unprotect(s7_scheme *sc, s7_pointer x); /* used in CM */
+#define s7_gc_stats(Sc, On)           s7_set_gc_stats(Sc, On)
+
+void s7_gc_unprotect(s7_scheme *sc, s7_pointer x);
 #endif
 
 
@@ -854,6 +855,10 @@ void s7_gc_unprotect(s7_scheme *sc, s7_pointer x); /* used in CM */
  * 
  *        s7 changes
  *
+ * 23-May:    added s7_scheme argument to s7_c_object_set_let.
+ * 19-May:    s7_gc_stats renamed s7_set_gc_stats.
+ * 7-May:     s7_gc_unprotect_via_stack and s7_gc_(un)protect_via_location.
+ * 22-Mar:    s7_float_format_precision. port-position. port-file.
  * 4-Jan-19:  morally-equal? -> equivalent?
  * --------
  * 29-Dec:    s7_c_type_set_getter|setter (implicit c-object access).
