@@ -55,11 +55,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "7-Feb-19"
+#define SND_DATE "26-June-19"
 #ifndef SND_VERSION
-#define SND_VERSION "19.1"
+#define SND_VERSION "19.5"
 #endif
 #define SND_MAJOR_VERSION "19"
-#define SND_MINOR_VERSION "1"
+#define SND_MINOR_VERSION "5"
 
 #endif
