@@ -2,16 +2,16 @@
 ;;; (dups size file alloc-lines): 
 ;;;    find all matches of "size" successive lines in "file" ignoring empty lines and leading/trailing whitespace
 ;;;    "alloc-lines" is any number bigger than the number of lines in "file"
-;;;    (dups 16 "s7.c" 91000) finds all 16-line matches in s7.c which has less than 91000 lines in all
+;;;    (dups 16 "s7.c" 91000) finds all 16-line matches in s7.c which (we wish) has less than 91000 lines in all
 
 (set! (*s7* 'heap-size) (* 2 1024000))
 
 (define dups 
-  (let ()
+  (let ((unique #f))
 
-    (define-constant (all-positive? v start end)
+    (define-constant (all-positive? start end)
       (do ((j end (- j 1)))
-	  ((or (negative? (int-vector-ref v j))
+	  ((or (vector-ref unique j)
 	       (= j start))
 	   j)))
 
@@ -21,6 +21,7 @@
 	    (lens (make-int-vector alloc-lines))
 	    (linenums (make-int-vector alloc-lines))
 	    (size-1 0))
+	(set! unique (make-vector alloc-lines #f))
 	
 	(call-with-input-file file
 	  (lambda (p)
@@ -57,7 +58,7 @@
 	      
 	      (set! size (min size total-lines))
 	      (set! size-1 (- size 1))
-	      ;; (format *stderr* "lines: ~S~%" total-lines)         ; 80263
+	      ;; (format *stderr* "lines: ~S~%" total-lines)         ; 80820
 
 	      ;; mark unmatchable strings
 	      (let ((sortv (make-vector total-lines)))
@@ -75,6 +76,7 @@
 				  (begin
 				    (unless matches
 				      (int-vector-set! lens (cdr current) unctr)
+				      (vector-set! unique (cdr current) #t) ; unique = (negative? (lens...))
 				      (set! unctr (- unctr 1)))
 				    (set! matches #f)
 				    (set! current srt))))
@@ -87,14 +89,14 @@
 		   (last-line (- total-lines size))
 		   (i 0 (+ i 1)))
 		  ((>= i last-line)) ; >= because i is set below
-		(let ((j (all-positive? lens i (+ i size-1))))   ; is a match possible?
+		(let ((j (all-positive? i (+ i size-1))))   ; is a match possible?
 		  (if (not (= j i))
 		      (set! i j)
 		      (let ((lenseq (subvector lens size i))
 			    (lineseq (subvector lines size i)))
 			(do ((k (+ i 1) (+ k 1)))
 			    ((>= k last-line))
-			  (let ((jk (all-positive? lens k (+ k size-1))))
+			  (let ((jk (all-positive? k (+ k size-1))))
 			    (if (not (= jk k))
 				(set! k jk)
 				(when (and (equal? lenseq (subvector lens size k))
@@ -120,11 +122,10 @@
 			(unless first
 			  (format *stderr* "~%")))))))))))))
 
-(dups 16 "s7.c" 91000)
-;(dups 2 "s7.c" 91000)
+(dups 16 "s7.c" 95000)
+;(dups 6 "s7.c" 95000)
 ;(dups 12 "ffitest.c" 2000)
 ;(dups 8 "ffitest.c" 2000)
-;(dups 16 "s7test.scm" 100000)
+;(dups 1 "s7test.scm" 102000)
 
-(s7-version)
 (exit)
