@@ -158,6 +158,9 @@
 (format *stderr* "~NC tmap ~NC~%" 20 #\- 20 #\-)
 (system "./repl tmap.scm")
 
+(format *stderr* "~NC tmat ~NC~%" 20 #\- 20 #\-)
+(system "./repl tmat.scm")
+
 (format *stderr* "~NC teq ~NC~%" 20 #\- 20 #\-)
 (system "./repl teq.scm")
 
@@ -191,6 +194,15 @@
 (format *stderr* "~NC tclo ~NC~%" 20 #\- 20 #\-)
 (system "./repl tclo.scm")
 
+(format *stderr* "~NC tvect ~NC~%" 20 #\- 20 #\-)
+(system "./repl tvect.scm")
+
+(format *stderr* "~NC trclo ~NC~%" 20 #\- 20 #\-)
+(system "./repl trclo.scm")
+
+(format *stderr* "~NC fbench ~NC~%" 20 #\- 20 #\-)
+(system "./repl fbench.scm")
+
 (format *stderr* "~NC tshoot ~NC~%" 20 #\- 20 #\-)
 (system "./repl tshoot.scm")
 
