@@ -37,8 +37,8 @@
 	((= i n))
       (if (> j i)
 	  (let ((temp (data j)))
-	    (set! (data j) (data i))
-	    (set! (data i) temp)))
+	    (vector-set! data j (vector-ref data i))
+	    (vector-set! data i temp)))
       (let ((m (/ n 2)))
 	(do () 
 	    ((not (<= 2 m j)))
@@ -53,16 +53,17 @@
 	   (theta (complex 0.0 (* pi dir)) (* theta 0.5)))
 	  ((= lg ipow))
 	(let ((wpc (exp theta))
-	      (wc 1.0))
+	      (wc 1.0)
+	      (tc 0.0))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
 	    (do ((jj 0 (+ jj 1))
 		 (i ii (+ i mmax))
 		 (j (+ ii prev) (+ j mmax)))
 		((>= jj pow))
-	      (let ((tc (* wc (data j))))
-		(set! (data j) (- (data i) tc))
-		(set! (data i) (+ (data i) tc))))
+	      (set! tc (* wc (vector-ref data j)))
+	      (vector-set! data j (- (vector-ref data i) tc))
+	      (vector-set! data i (+ (vector-ref data i) tc)))
 	    (set! wc (* wc wpc)))
 	  (set! prev mmax))))
     data))
@@ -112,12 +113,12 @@
 	 (j 0))
 	((= i n))
       (if (> j i)
-	  (let ((tempr (rl j))
-		(tempi (im j)))
-	    (set! (rl j) (rl i))
-	    (set! (im j) (im i))
-	    (set! (rl i) tempr)
-	    (set! (im i) tempi)))
+	  (let ((tempr (vector-ref rl j))
+		(tempi (vector-ref im j)))
+	    (vector-set! rl j (vector-ref rl i))
+	    (vector-set! im j (vector-ref im i))
+	    (vector-set! rl i tempr)
+	    (vector-set! im i tempi)))
       (let ((m (/ n 2)))
 	(do () 
 	    ((not (<= 2 m j)))
@@ -134,19 +135,21 @@
 	(let ((wpr (rationalize (cos theta)))
 	      (wpi (rationalize (sin theta)))
 	      (wr 1)
-	      (wi 0))
+	      (wi 0)
+	      (tempr 0)
+	      (tempi 0))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
 	    (do ((jj 0 (+ jj 1))
 		 (i ii (+ i mmax))
 		 (j (+ ii prev) (+ j mmax)))
 		((>= jj pow))
-	      (let ((tempr (rationalize (- (* wr (rl j)) (* wi (im j)))))
-		    (tempi (rationalize (+ (* wr (im j)) (* wi (rl j))))))
-		(set! (rl j) (rationalize (- (rl i) tempr)))
-		(set! (rl i) (rationalize (+ (rl i) tempr)))
-		(set! (im j) (rationalize (- (im i) tempi)))
-		(set! (im i) (rationalize (+ (im i) tempi)))))
+	      (set! tempr (rationalize (- (* wr (vector-ref rl j)) (* wi (vector-ref im j)))))
+	      (set! tempi (rationalize (+ (* wr (vector-ref im j)) (* wi (vector-ref rl j)))))
+	      (vector-set! rl j (rationalize (- (vector-ref rl i) tempr)))
+	      (vector-set! rl i (rationalize (+ (vector-ref rl i) tempr)))
+	      (vector-set! im j (rationalize (- (vector-ref im i) tempi)))
+	      (vector-set! im i (rationalize (+ (vector-ref im i) tempi))))
 	    (let ((wtemp wr))
 	      (set! wr (rationalize (- (* wr wpr) (* wi wpi))))
 	      (set! wi (rationalize (+ (* wi wpr) (* wtemp wpi))))))
@@ -177,7 +180,7 @@
     (let ((mx 0.0))
       (do ((i 0 (+ i 1)))
 	  ((= i fft-size))
-	(set! mx (max mx (abs (fvr i)) (abs (fvi i)))))
+	(set! mx (max mx (abs (vector-ref fvr i)) (abs (vector-ref fvi i)))))
       (format () "noise: ~A~%" (* 1.0 mx)))))
 
 (define (ratio-test)
@@ -187,7 +190,7 @@
     (do ((i 0 (+ i 1))
 	 (x 0.0 (+ x scl)))
 	((= i fft-size))
-      (set! (fvr i) (rationalize (sin x))))
+      (vector-set! fvr i (rationalize (sin x))))
     (ratio-fft fvr fvi fft-size 1)
     (ratio-checker fvr fvi)
     (ratio-fft #f #f fft-size 1)
@@ -833,6 +836,7 @@
     (test (bigfv (ash 1 31)) 3))
   (clear-and-gc))
 
+
 (define (int-vector-fft rl im n dir)
   (when rl
     (let ((tempr 0.0)
@@ -939,7 +943,6 @@
 (int-vector-test)
 (clear-and-gc)
 
-
 ;; --------------------------------------------------------------------------------
 (format () "~%vectors...~%")
 (when (> total-memory (* 9 big-size))
@@ -1203,12 +1206,12 @@
 	 (j 0))
 	((= i n))
       (if (> j i)
-	  (let ((tempr (rl j))
-		(tempi (im j)))
-	    (set! (rl j) (rl i))
-	    (set! (im j) (im i))
-	    (set! (rl i) tempr)
-	    (set! (im i) tempi)))
+	  (let ((tempr (block-ref rl j))
+		(tempi (block-ref im j)))
+	    (block-set! rl j (block-ref rl i))
+	    (block-set! im j (block-ref im i))
+	    (block-set! rl i tempr)
+	    (block-set! im i tempi)))
       (let ((m (/ n 2)))
 	(do () 
 	    ((not (<= 2 m j)))
@@ -1235,12 +1238,12 @@
 		 (j (+ ii prev) (+ j mmax))
 		 (jj 0 (+ jj 1)))
 		((>= jj pow))
-	      (set! tempr (- (* wr (rl j)) (* wi (im j))))
-	      (set! tempi (+ (* wr (im j)) (* wi (rl j))))
-	      (set! (rl j) (- (rl i) tempr))
-	      (set! (rl i) (+ (rl i) tempr))
-	      (set! (im j) (- (im i) tempi))
-	      (set! (im i) (+ (im i) tempi)))
+	      (set! tempr (- (* wr (block-ref rl j)) (* wi (block-ref im j))))
+	      (set! tempi (+ (* wr (block-ref im j)) (* wi (block-ref rl j))))
+	      (block-set! rl j (- (block-ref rl i) tempr))
+	      (block-set! rl i (+ (block-ref rl i) tempr))
+	      (block-set! im j (- (block-ref im i) tempi))
+	      (block-set! im i (+ (block-ref im i) tempi)))
 	    (set! wtemp wr)
 	    (set! wr (- (* wr wpr) (* wi wpi)))
 	    (set! wi (+ (* wi wpr) (* wtemp wpi))))
@@ -1254,7 +1257,7 @@
     (do ((i 0 (+ i 1))
 	 (x 0.0 (+ x scl)))
 	((= i fft-size))
-      (set! (fvr i) (sin x)))
+      (block-set! fvr i (sin x)))
     (block-fft fvr fvi fft-size 1)
     (do ((mx 0.0)
 	 (mxloc 0)
@@ -1275,7 +1278,7 @@
 	 (i 0 (+ i 1)))
 	((= i fft-size)
 	 (format () "noise: ~A~%" mx))
-      (set! mx (max mx (abs (fvr i)) (abs (fvi i)))))
+      (set! mx (max mx (abs (block-ref fvr i)) (abs (block-ref fvi i)))))
     (block-fft #f #f fft-size 1)))
 (block-test)
 
@@ -2034,16 +2037,17 @@
 	   (theta (complex 0.0 (* pi dir)) (* theta 0.5)))
 	  ((= lg ipow))
 	(let ((wpc (exp theta))
-	      (wc 1.0))
+	      (wc 1.0)
+	      (tc 0.0))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
 	    (do ((jj 0 (+ jj 1))
 		 (i ii (+ i mmax))
 		 (j (+ ii prev) (+ j mmax)))
 		((>= jj pow))
-	      (let ((tc (* wc (old-value (vector-ref data j)))))
-		(vector-set! data j (new-value (- (old-value (vector-ref data i)) tc)))
-		(vector-set! data i (new-value (+ (old-value (vector-ref data i)) tc)))))
+	      (set! tc (* wc (old-value (vector-ref data j))))
+	      (vector-set! data j (new-value (- (old-value (vector-ref data i)) tc)))
+	      (vector-set! data i (new-value (+ (old-value (vector-ref data i)) tc))))
 	    (set! wc (* wc wpc)))
 	  (set! prev mmax))))
     data))
@@ -2346,8 +2350,7 @@
 (complex-closure-test)
 
 ;(clear-and-gc)
-
-
-(s7-version)
-
 ;(*s7* 'memory-usage)
+
+(exit)
+
