@@ -58,7 +58,7 @@
 	))))
 
 (define (iv-tst len)
-  (let ((fv (make-int-vector len 0)))
+  (let ((fv (make-int-vector len)))
     (if (not (= (length fv) len))
 	(format *stderr* "int-vector length ~A: ~A~%" fv (length fv)))
     (fill! fv 0)
@@ -268,8 +268,8 @@
        (v-tst (expt b i))
        (s-tst (expt b i))
        (p-tst (expt b i))))
-   (list 2 3 4 7 10)
-   (list 12 4 3 6 6)))
+   '(2 3 4 7 10)
+   '(12 4 3 6 6)))
 
 (test-it)
 
@@ -344,7 +344,7 @@
 	(do ((j (ash (* i i) -1) (+ j i)))
 	    ((>= j visited-range))
 	  (boolean-vector-set! visited j))))
-    (let ((rc (make-int-vector (+ n 1) 0))
+    (let ((rc (make-int-vector (+ n 1)))
 	  (rcp 0)
 	  (lim (+ n 1)))
       (do ((i 3 (+ i 2)))
@@ -356,7 +356,7 @@
 (define (getr n)
   (let* ((odd-bound (ash (+ n 1) -1))
 	 (prime-list (odd-get n))
-	 (result (make-int-vector odd-bound 0))
+	 (result (make-int-vector odd-bound))
 	 (n2 (/ n 2))) ; this optimization suggested by "Peter" (in comp.lang.lisp)
     (do ((i 0 (+ i 1)))
 	((= i odd-bound))
@@ -385,6 +385,5 @@
 
 ;;; (display (getr 500000000)) ;50660591862310323
 
-(s7-version)
 (exit)
 
