@@ -58,10 +58,8 @@
 
 (define (wc)
   (let ((newk 0)
-	(nl 0)
 	(nw 0)
 	(nc 0)
-	(inword #f)
 	(port (open-input-file "/home/bil/test/scheme/bench/src/bib")))
     (do ((str (read-line port) (read-line port))
 	 (nl 0 (+ nl 1)))
@@ -105,7 +103,7 @@
 	  ((> (string-length s) n))
 	(set! s (string-append "123" s "456" s "789"))
 	(set! s (string-append
-		 (substring s (quotient (string-length s) 2) (string-length s))
+		 (substring s (quotient (string-length s) 2))
 		 (substring s 0 (+ 1 (quotient (string-length s) 2)))))))))
 
 (display (string-cat 500000)) (newline) ; 524278
@@ -147,53 +145,52 @@
 
 ;;; --------------------------------------------------------------------------------
 
-;;; this one is not very good (unsafe non-tc recursion is slow)
+;;; this one is not very good
 
 (define binary-tree
-  (let ((new-tree-node cons))
-
+  (let ()
     (define (item-check tree)
-      (if (car tree)
-	  (+ 1 (item-check (car tree)) (item-check (cdr tree)))
-	  1))
+      (if (not (car tree))
+	  1
+	  (+ 1 (item-check (car tree)) (item-check (cdr tree)))))
     
     (define (bottom-up-tree depth)
       (if (zero? depth)
-	  (new-tree-node #f #f)
-	  (new-tree-node (bottom-up-tree (- depth 1)) 
-			 (bottom-up-tree (- depth 1)))))
+	  (cons #f #f)
+	  (cons (bottom-up-tree (- depth 1)) 
+		(bottom-up-tree (- depth 1)))))
     
     (lambda (N)
       (let* ((min-depth 4)
-	     (max-depth (if (> (+ min-depth 2) N) (+ min-depth 2) N))
+	     (max-depth (max (+ min-depth 2) N))
 	     (stretch-depth (+ max-depth 1))
 	     (stretch-tree (bottom-up-tree stretch-depth)))
 	(format *stderr* "stretch tree of depth ~D~30Tcheck: ~D~%" stretch-depth (item-check stretch-tree))
 	(let ((long-lived-tree (bottom-up-tree max-depth)))
 	  (do ((depth min-depth (+ depth 2)))
 	      ((> depth max-depth))
-	    (let ((iterations (expt 2 (+ max-depth (- depth) min-depth))))
+	    (let ((iterations (expt 2 (- (+ max-depth min-depth) depth))))
 	      (do ((i 0 (+ i 1))
 		   (check 0 (+ check (item-check (bottom-up-tree depth)))))
 		  ((= i iterations)
 		   (format *stderr* "~D~9Ttrees of depth ~D~30Tcheck: ~D~%" iterations depth check)))))
 	  (format *stderr* "long lived tree of depth ~D~30Tcheck: ~D~%" max-depth (item-check long-lived-tree)))))))
 
-;(binary-tree 21) ; 84.4 secs if (set! (*s7* 'heap-size) (* 36 1024000))
+;(binary-tree 21) ; 30 secs if (set! (*s7* 'heap-size) (* 24 1024000))
+(binary-tree 6)
+
+;;; stretch      tree of  depth 22	 check: 8388607
+;;; 2097152	 trees of depth 4	 check: 65011712
+;;; 524288	 trees of depth 6	 check: 66584576
+;;; 131072	 trees of depth 8	 check: 66977792
+;;; 32768	 trees of depth 10	 check: 67076096
+;;; 8192	 trees of depth 12	 check: 67100672
+;;; 2048	 trees of depth 14	 check: 67106816
+;;; 512	         trees of depth 16	 check: 67108352
+;;; 128	         trees of depth 18	 check: 67108736
+;;; 32	         trees of depth 20	 check: 67108832
+;;; long lived   tree of  depth 21	 check: 4194303
 
-"
-stretch tree of depth 22	 check: 8388607
-2097152	 trees of depth 4	 check: 65011712
-524288	 trees of depth 6	 check: 66584576
-131072	 trees of depth 8	 check: 66977792
-32768	 trees of depth 10	 check: 67076096
-8192	 trees of depth 12	 check: 67100672
-2048	 trees of depth 14	 check: 67106816
-512	 trees of depth 16	 check: 67108352
-128	 trees of depth 18	 check: 67108736
-32	 trees of depth 20	 check: 67108832
-long lived tree of depth 21	 check: 4194303
-"
 
 ;;; --------------------------------------------------------------------------------
 
@@ -206,24 +203,53 @@ long lived tree of depth 21	 check: 4194303
 	(if (logbit? n 0)
 	    (set! n (+ (* 3 n) 1))
 	    (set! n (ash n -1)))))
-    (lambda ()
+    (lambda (N)
       (let ((len 0)
 	    (num 0)
 	    (cur 0))
 	(do ((i 1 (+ i 1)))
-	    ((= i 300000))
+	    ((= i N)) ; 300000))
 	  (set! cur (collatz-count-until-1 i))
 	  (when (< len cur)
 	    (set! len cur)
 	    (set! num i)))
 	(format *stderr* "Maximum stopping distance ~D, starting number ~D\n" len num)))))
 
-;(collatz)
+;(collatz 300000)
 ;; Maximum stopping distance 442, starting number 230631
 ;; .66 secs
+(collatz 20000)
 
 ;;; --------------------------------------------------------------------------------
 
+(define prime?                         ; from exobrain.se
+  (let ((increments (list 4 2 4 2 4 6 2 6)))
+    (set-cdr! (list-tail increments 7) increments)
+    (lambda (z)
+      (or (memq z '(2 3 5 7))          ; memv...
+	  (and (positive? (remainder z 2))
+	       (positive? (remainder z 3))	  
+	       (positive? (remainder z 5))	  
+	       (positive? (remainder z 7))
+	       (do ((L increments)
+		    (lim (sqrt z))
+		    (divisor 11 (+ divisor (car L))))
+		   ((or (zero? (remainder z divisor))
+			(>= divisor lim))
+		    (> divisor lim))
+		 (set! L (cdr L))))))))
+
+(let ()
+  (define (count-primes limit)          ; for limit=10000000 12.7 secs 664579
+    (let ((primes 0))
+      (do ((i 2 (+ i 1)))
+	  ((= i limit)
+	   primes)
+	(if (prime? i)
+	    (set! primes (+ primes 1))))))
+
+  (display (count-primes 100000)) (newline)) ; 9592
+
+;;; --------------------------------------------------------------------------------
 
-(s7-version)
 (exit)
